==> mingw-w64-i686-opencascade-7.6.2-1-any.pkg.tar.zst: mingw32/lib/cmake/opencascade/OpenCASCADEModelingAlgorithmsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKGeomAlgo" for configuration "Release"
set_property(TARGET TKGeomAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKGeomAlgo PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKGeomAlgo.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKGeomAlgo.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKGeomAlgo )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKGeomAlgo "${_IMPORT_PREFIX}/lib\/libTKGeomAlgo.dll.a" "${_IMPORT_PREFIX}/bin\/libTKGeomAlgo.dll" )

# Import target "TKTopAlgo" for configuration "Release"
set_property(TARGET TKTopAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTopAlgo PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKTopAlgo.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKTopAlgo.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKTopAlgo )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKTopAlgo "${_IMPORT_PREFIX}/lib\/libTKTopAlgo.dll.a" "${_IMPORT_PREFIX}/bin\/libTKTopAlgo.dll" )

# Import target "TKPrim" for configuration "Release"
set_property(TARGET TKPrim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKPrim PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKPrim.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKPrim.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKPrim )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKPrim "${_IMPORT_PREFIX}/lib\/libTKPrim.dll.a" "${_IMPORT_PREFIX}/bin\/libTKPrim.dll" )

# Import target "TKBO" for configuration "Release"
set_property(TARGET TKBO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBO PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKBO.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKBO.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKBO )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKBO "${_IMPORT_PREFIX}/lib\/libTKBO.dll.a" "${_IMPORT_PREFIX}/bin\/libTKBO.dll" )

# Import target "TKShHealing" for configuration "Release"
set_property(TARGET TKShHealing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKShHealing PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKShHealing.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKShHealing.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKShHealing )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKShHealing "${_IMPORT_PREFIX}/lib\/libTKShHealing.dll.a" "${_IMPORT_PREFIX}/bin\/libTKShHealing.dll" )

# Import target "TKBool" for configuration "Release"
set_property(TARGET TKBool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBool PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKBool.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKBool.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKBool )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKBool "${_IMPORT_PREFIX}/lib\/libTKBool.dll.a" "${_IMPORT_PREFIX}/bin\/libTKBool.dll" )

# Import target "TKHLR" for configuration "Release"
set_property(TARGET TKHLR APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKHLR PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKHLR.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKHLR.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKHLR )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKHLR "${_IMPORT_PREFIX}/lib\/libTKHLR.dll.a" "${_IMPORT_PREFIX}/bin\/libTKHLR.dll" )

# Import target "TKFillet" for configuration "Release"
set_property(TARGET TKFillet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFillet PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKFillet.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKFillet.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKFillet )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKFillet "${_IMPORT_PREFIX}/lib\/libTKFillet.dll.a" "${_IMPORT_PREFIX}/bin\/libTKFillet.dll" )

# Import target "TKOffset" for configuration "Release"
set_property(TARGET TKOffset APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKOffset PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKOffset.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKOffset.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKOffset )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKOffset "${_IMPORT_PREFIX}/lib\/libTKOffset.dll.a" "${_IMPORT_PREFIX}/bin\/libTKOffset.dll" )

# Import target "TKFeat" for configuration "Release"
set_property(TARGET TKFeat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFeat PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKFeat.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKFeat.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKFeat )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKFeat "${_IMPORT_PREFIX}/lib\/libTKFeat.dll.a" "${_IMPORT_PREFIX}/bin\/libTKFeat.dll" )

# Import target "TKMesh" for configuration "Release"
set_property(TARGET TKMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKMesh PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKMesh.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKMesh.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKMesh )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKMesh "${_IMPORT_PREFIX}/lib\/libTKMesh.dll.a" "${_IMPORT_PREFIX}/bin\/libTKMesh.dll" )

# Import target "TKXMesh" for configuration "Release"
set_property(TARGET TKXMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXMesh PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKXMesh.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKXMesh.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS TKXMesh )
list(APPEND _IMPORT_CHECK_FILES_FOR_TKXMesh "${_IMPORT_PREFIX}/lib\/libTKXMesh.dll.a" "${_IMPORT_PREFIX}/bin\/libTKXMesh.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-i686-opencascade-7.7.0-1-any.pkg.tar.zst: mingw32/lib/cmake/opencascade/OpenCASCADEModelingAlgorithmsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKGeomAlgo" for configuration "Release"
set_property(TARGET TKGeomAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKGeomAlgo PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKGeomAlgo.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKGeomAlgo.dll"
  )

list(APPEND _cmake_import_check_targets TKGeomAlgo )
list(APPEND _cmake_import_check_files_for_TKGeomAlgo "${_IMPORT_PREFIX}/lib\/libTKGeomAlgo.dll.a" "${_IMPORT_PREFIX}/bin\/libTKGeomAlgo.dll" )

# Import target "TKTopAlgo" for configuration "Release"
set_property(TARGET TKTopAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTopAlgo PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKTopAlgo.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKTopAlgo.dll"
  )

list(APPEND _cmake_import_check_targets TKTopAlgo )
list(APPEND _cmake_import_check_files_for_TKTopAlgo "${_IMPORT_PREFIX}/lib\/libTKTopAlgo.dll.a" "${_IMPORT_PREFIX}/bin\/libTKTopAlgo.dll" )

# Import target "TKPrim" for configuration "Release"
set_property(TARGET TKPrim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKPrim PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKPrim.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKPrim.dll"
  )

list(APPEND _cmake_import_check_targets TKPrim )
list(APPEND _cmake_import_check_files_for_TKPrim "${_IMPORT_PREFIX}/lib\/libTKPrim.dll.a" "${_IMPORT_PREFIX}/bin\/libTKPrim.dll" )

# Import target "TKBO" for configuration "Release"
set_property(TARGET TKBO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBO PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKBO.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKBO.dll"
  )

list(APPEND _cmake_import_check_targets TKBO )
list(APPEND _cmake_import_check_files_for_TKBO "${_IMPORT_PREFIX}/lib\/libTKBO.dll.a" "${_IMPORT_PREFIX}/bin\/libTKBO.dll" )

# Import target "TKShHealing" for configuration "Release"
set_property(TARGET TKShHealing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKShHealing PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKShHealing.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKShHealing.dll"
  )

list(APPEND _cmake_import_check_targets TKShHealing )
list(APPEND _cmake_import_check_files_for_TKShHealing "${_IMPORT_PREFIX}/lib\/libTKShHealing.dll.a" "${_IMPORT_PREFIX}/bin\/libTKShHealing.dll" )

# Import target "TKBool" for configuration "Release"
set_property(TARGET TKBool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBool PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKBool.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKBool.dll"
  )

list(APPEND _cmake_import_check_targets TKBool )
list(APPEND _cmake_import_check_files_for_TKBool "${_IMPORT_PREFIX}/lib\/libTKBool.dll.a" "${_IMPORT_PREFIX}/bin\/libTKBool.dll" )

# Import target "TKHLR" for configuration "Release"
set_property(TARGET TKHLR APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKHLR PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKHLR.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKHLR.dll"
  )

list(APPEND _cmake_import_check_targets TKHLR )
list(APPEND _cmake_import_check_files_for_TKHLR "${_IMPORT_PREFIX}/lib\/libTKHLR.dll.a" "${_IMPORT_PREFIX}/bin\/libTKHLR.dll" )

# Import target "TKFillet" for configuration "Release"
set_property(TARGET TKFillet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFillet PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKFillet.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKFillet.dll"
  )

list(APPEND _cmake_import_check_targets TKFillet )
list(APPEND _cmake_import_check_files_for_TKFillet "${_IMPORT_PREFIX}/lib\/libTKFillet.dll.a" "${_IMPORT_PREFIX}/bin\/libTKFillet.dll" )

# Import target "TKOffset" for configuration "Release"
set_property(TARGET TKOffset APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKOffset PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKOffset.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKOffset.dll"
  )

list(APPEND _cmake_import_check_targets TKOffset )
list(APPEND _cmake_import_check_files_for_TKOffset "${_IMPORT_PREFIX}/lib\/libTKOffset.dll.a" "${_IMPORT_PREFIX}/bin\/libTKOffset.dll" )

# Import target "TKFeat" for configuration "Release"
set_property(TARGET TKFeat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFeat PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKFeat.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKFeat.dll"
  )

list(APPEND _cmake_import_check_targets TKFeat )
list(APPEND _cmake_import_check_files_for_TKFeat "${_IMPORT_PREFIX}/lib\/libTKFeat.dll.a" "${_IMPORT_PREFIX}/bin\/libTKFeat.dll" )

# Import target "TKMesh" for configuration "Release"
set_property(TARGET TKMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKMesh PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKMesh.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKMesh.dll"
  )

list(APPEND _cmake_import_check_targets TKMesh )
list(APPEND _cmake_import_check_files_for_TKMesh "${_IMPORT_PREFIX}/lib\/libTKMesh.dll.a" "${_IMPORT_PREFIX}/bin\/libTKMesh.dll" )

# Import target "TKXMesh" for configuration "Release"
set_property(TARGET TKXMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXMesh PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib\/libTKXMesh.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin\/libTKXMesh.dll"
  )

list(APPEND _cmake_import_check_targets TKXMesh )
list(APPEND _cmake_import_check_files_for_TKXMesh "${_IMPORT_PREFIX}/lib\/libTKXMesh.dll.a" "${_IMPORT_PREFIX}/bin\/libTKXMesh.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
